@@ -170,7 +170,7 @@ kendallsTauGalambosCopula <- function(copula) {
 }
 
 calibKendallsTauGalambosCopula <- function(copula, tau) {
-  if (any(tau < 0)) warning("tau is out of range (0, 1)")
+  if (any(tau < 0)) warning("tau is out of the range (0, 1)")
   galambosTauInv <- approxfun(x = .galambosTau$assoMeasFun$fm$ysmth,
                               y = .galambosTau$assoMeasFun$fm$x, rule = 2)
   
