@@ -168,7 +168,7 @@ tailIndexGumbelCopula <- function(copula, ...) {
 
 
 calibKendallsTauGumbelCopula <- function(copula, tau) {
-  if (any(tau < 0)) warning("tau is out of range (0, 1)")
+  if (any(tau < 0)) warning("tau is out of the range [0, 1]")
   ifelse(tau < 0, 1, 1/(1 - tau))
 }
 
@@ -199,7 +199,7 @@ spearmansRhoGumbelCopula <- function(copula) {
 
 
 calibSpearmansRhoGumbelCopula <- function(copula, rho) {
-  if (any(rho < 0)) warning("rho is out of range (0, 1)")
+  if (any(rho < 0)) warning("rho is out of the range [0, 1]")
   gumbelRhoInv <- approxfun(x = .gumbelRho$assoMeasFun$fm$ysmth,
                             y = .gumbelRho$assoMeasFun$fm$x, rule = 2)
   
