@@ -82,7 +82,7 @@ dtawnCopula <- function(copula, u) {
 
 kendallsTauTawnCopula <- function(copula) {
   alpha <- copula@parameters[1]
-  ## the range of tau is (0,  0.4183992)
+  ## the range of tau is [0,  0.4183992]
   8 * atan(sqrt(alpha / (4 - alpha))) / sqrt(alpha * (4 - alpha)) - 2
 }
 
@@ -90,7 +90,7 @@ calibKendallsTauTawnCopula <- function(copula, tau) {
   alpha <- 1
   taumax <- 8 * atan(sqrt(alpha / (4 - alpha))) / sqrt(alpha * (4 - alpha)) - 2
   bad <- (tau < 0 | tau >= taumax)
-  if (any(bad)) warning("tau is out of range (0, 0.4183992)")
+  if (any(bad)) warning("tau is out of the range [0, 0.4183992]")
   ifelse(tau < 0, 0,
          ifelse(tau >= taumax, 1, calibKendallsTauCopula(copula, tau)))
 }
@@ -119,7 +119,7 @@ tauDerTawnCopula <- function(copula) {
 spearmansRhoTawnCopula <- function(copula) {
   alpha <- copula@parameters[1]
   ## from Mathematica
-  ## the range of rho is (0, 0.58743682)
+  ## the range of rho is [0, 0.58743682]
   integ <- ( (8 - alpha) * alpha + 8 * sqrt( (8 - alpha) * alpha ) * atan(sqrt(alpha) / sqrt(8 - alpha)) ) / ( (8 - alpha)^2 * alpha )
   if(alpha == 0) 0 else 12 * integ - 3
 }
@@ -128,7 +128,7 @@ calibSpearmansRhoTawnCopula <- function(copula, rho) {
   alpha <- 1
   rhomax <- 12 * ( (8 - alpha) * alpha + 8 * sqrt( (8 - alpha) * alpha ) * atan(sqrt(alpha) / sqrt(8 - alpha)) ) / ( (8 - alpha)^2 * alpha ) - 3
   bad <- (rho < 0 | rho >= rhomax)
-  if (any(bad)) warning("rho is out of range (0, 0.4183992)")
+  if (any(bad)) warning("rho is out of range [0, 0.58743682]")
   ifelse(rho < 0, 0,
          ifelse(rho >= rhomax, 1, calibSpearmansRhoCopula(copula, rho)))
 }
